@@ -26,7 +26,7 @@ doj_press_releases <- function(n_results=50, search_direction="DESC", keyword=NU
   for(i in 1:nrow(results)) {
     # Insert by row if nested list isn't empty
     if(length(results[[4]][[i]]) > 0) {
-      results[[13]][[i]] <- paste0(results[[4]][[i]][[2]], collapse = " ", sep = ",") } }
+      results$name[i] <- paste0(results[[4]][[i]][[2]], collapse = " ", sep = ",") } }
 
   results <- results %>%
     select(-component, -attachment)
